.. pypitch documentation master file, created by
   sphinx-quickstart on Thu Apr  9 20:03:35 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pypitch's documentation!
===================================

PyPitch is a C++-extension in Python to analyse audio streams for pitch.


.. toctree::
   :maxdepth: 2
   :caption: User guide

   installation
   usage
   history
   releasenotes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
